# EmploymentsRetrieve404Response


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**detail** | **str** | No instance matches the given query. | [optional] 

## Example

```python
from openapi_client.models.employments_retrieve404_response import EmploymentsRetrieve404Response

# TODO update the JSON string below
json = "{}"
# create an instance of EmploymentsRetrieve404Response from a JSON string
employments_retrieve404_response_instance = EmploymentsRetrieve404Response.from_json(json)
# print the JSON string representation of the object
print(EmploymentsRetrieve404Response.to_json())

# convert the object into a dict
employments_retrieve404_response_dict = employments_retrieve404_response_instance.to_dict()
# create an instance of EmploymentsRetrieve404Response from a dict
employments_retrieve404_response_from_dict = EmploymentsRetrieve404Response.from_dict(employments_retrieve404_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


